Class: Google::Apis::ManagedkafkaV1::AclEntry

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/managedkafka_v1/classes.rb,
lib/google/apis/managedkafka_v1/representations.rb,
lib/google/apis/managedkafka_v1/representations.rb

Overview

Represents the access granted for a given Resource Pattern in an ACL.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AclEntry

Returns a new instance of AclEntry.



149
150
151
# File 'lib/google/apis/managedkafka_v1/classes.rb', line 149

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#hostString

Required. The host. Must be set to "*" for Managed Service for Apache Kafka. Corresponds to the JSON property host

Returns:

  • (String)


124
125
126
# File 'lib/google/apis/managedkafka_v1/classes.rb', line 124

def host
  @host
end

#operationString

Required. The operation type. Allowed values are (case insensitive): ALL, READ, WRITE, CREATE, DELETE, ALTER, DESCRIBE, CLUSTER_ACTION, DESCRIBE_CONFIGS, ALTER_CONFIGS, and IDEMPOTENT_WRITE. See https://kafka.apache.org/ documentation/#operations_resources_and_protocols for valid combinations of resource_type and operation for different Kafka API requests. Corresponds to the JSON property operation

Returns:

  • (String)


133
134
135
# File 'lib/google/apis/managedkafka_v1/classes.rb', line 133

def operation
  @operation
end

#permission_typeString

Required. The permission type. Accepted values are (case insensitive): ALLOW, DENY. Corresponds to the JSON property permissionType

Returns:

  • (String)


139
140
141
# File 'lib/google/apis/managedkafka_v1/classes.rb', line 139

def permission_type
  @permission_type
end

#principalString

Required. The principal. Specified as Google Cloud account, with the Kafka StandardAuthorizer prefix "User:". For example: "User:test-kafka-client@test- project.iam.gserviceaccount.com". Can be the wildcard "User:*" to refer to all users. Corresponds to the JSON property principal

Returns:

  • (String)


147
148
149
# File 'lib/google/apis/managedkafka_v1/classes.rb', line 147

def principal
  @principal
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



154
155
156
157
158
159
# File 'lib/google/apis/managedkafka_v1/classes.rb', line 154

def update!(**args)
  @host = args[:host] if args.key?(:host)
  @operation = args[:operation] if args.key?(:operation)
  @permission_type = args[:permission_type] if args.key?(:permission_type)
  @principal = args[:principal] if args.key?(:principal)
end