Class: Google::Apis::ManagedkafkaV1::AddAclEntryResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/managedkafka_v1/classes.rb,
lib/google/apis/managedkafka_v1/representations.rb,
lib/google/apis/managedkafka_v1/representations.rb

Overview

Response for AddAclEntry.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AddAclEntryResponse

Returns a new instance of AddAclEntryResponse.



178
179
180
# File 'lib/google/apis/managedkafka_v1/classes.rb', line 178

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#aclGoogle::Apis::ManagedkafkaV1::Acl

Represents the set of ACLs for a given Kafka Resource Pattern, which consists of resource_type, resource_name and pattern_type. Corresponds to the JSON property acl



170
171
172
# File 'lib/google/apis/managedkafka_v1/classes.rb', line 170

def acl
  @acl
end

#acl_createdBoolean Also known as: acl_created?

Whether the acl was created as a result of adding the acl entry. Corresponds to the JSON property aclCreated

Returns:

  • (Boolean)


175
176
177
# File 'lib/google/apis/managedkafka_v1/classes.rb', line 175

def acl_created
  @acl_created
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



183
184
185
186
# File 'lib/google/apis/managedkafka_v1/classes.rb', line 183

def update!(**args)
  @acl = args[:acl] if args.key?(:acl)
  @acl_created = args[:acl_created] if args.key?(:acl_created)
end