Class: Google::Apis::ManagedkafkaV1::CertificateAuthorityServiceConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/managedkafka_v1/classes.rb,
lib/google/apis/managedkafka_v1/representations.rb,
lib/google/apis/managedkafka_v1/representations.rb

Overview

A configuration for the Google Certificate Authority Service.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CertificateAuthorityServiceConfig

Returns a new instance of CertificateAuthorityServiceConfig.



270
271
272
# File 'lib/google/apis/managedkafka_v1/classes.rb', line 270

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ca_poolString

Required. The name of the CA pool to pull CA certificates from. Structured like: projects/project/locations/location/caPools/ca_pool. The CA pool does not need to be in the same project or location as the Kafka cluster. Corresponds to the JSON property caPool

Returns:

  • (String)


268
269
270
# File 'lib/google/apis/managedkafka_v1/classes.rb', line 268

def ca_pool
  @ca_pool
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



275
276
277
# File 'lib/google/apis/managedkafka_v1/classes.rb', line 275

def update!(**args)
  @ca_pool = args[:ca_pool] if args.key?(:ca_pool)
end