Class: Google::Apis::ManagedkafkaV1::ConnectAccessConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/managedkafka_v1/classes.rb,
lib/google/apis/managedkafka_v1/representations.rb,
lib/google/apis/managedkafka_v1/representations.rb

Overview

The configuration of access to the Kafka Connect cluster.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ConnectAccessConfig

Returns a new instance of ConnectAccessConfig.



461
462
463
# File 'lib/google/apis/managedkafka_v1/classes.rb', line 461

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#network_configsArray<Google::Apis::ManagedkafkaV1::ConnectNetworkConfig>

Required. Virtual Private Cloud (VPC) networks that must be granted direct access to the Kafka Connect cluster. Minimum of 1 network is required. Maximum 10 networks can be specified. Corresponds to the JSON property networkConfigs



459
460
461
# File 'lib/google/apis/managedkafka_v1/classes.rb', line 459

def network_configs
  @network_configs
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



466
467
468
# File 'lib/google/apis/managedkafka_v1/classes.rb', line 466

def update!(**args)
  @network_configs = args[:network_configs] if args.key?(:network_configs)
end