Class: Google::Apis::ManagedkafkaV1::ConnectGcpConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/managedkafka_v1/classes.rb,
lib/google/apis/managedkafka_v1/representations.rb,
lib/google/apis/managedkafka_v1/representations.rb

Overview

Configuration properties for a Kafka Connect cluster deployed to Google Cloud Platform.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ConnectGcpConfig

Returns a new instance of ConnectGcpConfig.



574
575
576
# File 'lib/google/apis/managedkafka_v1/classes.rb', line 574

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#access_configGoogle::Apis::ManagedkafkaV1::ConnectAccessConfig

The configuration of access to the Kafka Connect cluster. Corresponds to the JSON property accessConfig



565
566
567
# File 'lib/google/apis/managedkafka_v1/classes.rb', line 565

def access_config
  @access_config
end

#secret_pathsArray<String>

Optional. Secrets to load into workers. Exact SecretVersions from Secret Manager must be provided -- aliases are not supported. Up to 32 secrets may be loaded into one cluster. Format: projects//secrets//versions/ Corresponds to the JSON property secretPaths

Returns:

  • (Array<String>)


572
573
574
# File 'lib/google/apis/managedkafka_v1/classes.rb', line 572

def secret_paths
  @secret_paths
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



579
580
581
582
# File 'lib/google/apis/managedkafka_v1/classes.rb', line 579

def update!(**args)
  @access_config = args[:access_config] if args.key?(:access_config)
  @secret_paths = args[:secret_paths] if args.key?(:secret_paths)
end