Class: Google::Apis::ManagedkafkaV1::Connector

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/managedkafka_v1/classes.rb,
lib/google/apis/managedkafka_v1/representations.rb,
lib/google/apis/managedkafka_v1/representations.rb

Overview

A Kafka Connect connector in a given ConnectCluster.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Connector

Returns a new instance of Connector.



665
666
667
# File 'lib/google/apis/managedkafka_v1/classes.rb', line 665

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#configsHash<String,String>

Optional. Connector config as keys/values. The keys of the map are connector property names, for example: connector.class, tasks.max, key.converter. Corresponds to the JSON property configs

Returns:

  • (Hash<String,String>)


639
640
641
# File 'lib/google/apis/managedkafka_v1/classes.rb', line 639

def configs
  @configs
end

#nameString

Identifier. The name of the connector. Structured like: projects/project/ locations/location/connectClusters/connect_cluster/connectors/connector Corresponds to the JSON property name

Returns:

  • (String)


645
646
647
# File 'lib/google/apis/managedkafka_v1/classes.rb', line 645

def name
  @name
end

#stateString

Output only. The current state of the connector. Corresponds to the JSON property state

Returns:

  • (String)


650
651
652
# File 'lib/google/apis/managedkafka_v1/classes.rb', line 650

def state
  @state
end

#task_restart_policyGoogle::Apis::ManagedkafkaV1::TaskRetryPolicy

Task Retry Policy is implemented on a best-effort basis. The default policy retries tasks with a minimum_backoff of 60 seconds, and a maximum_backoff of 12 hours. You can disable the policy by setting the task_retry_disabled field to true. Retry delay will be exponential based on provided minimum and maximum backoffs. https://en.wikipedia.org/wiki/Exponential_backoff. Note that the delay between consecutive task restarts may not always precisely match the configured settings. This can happen when the ConnectCluster is in rebalancing state or if the ConnectCluster is unresponsive etc. The default values for minimum and maximum backoffs are 60 seconds and 12 hours respectively. Corresponds to the JSON property taskRestartPolicy



663
664
665
# File 'lib/google/apis/managedkafka_v1/classes.rb', line 663

def task_restart_policy
  @task_restart_policy
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



670
671
672
673
674
675
# File 'lib/google/apis/managedkafka_v1/classes.rb', line 670

def update!(**args)
  @configs = args[:configs] if args.key?(:configs)
  @name = args[:name] if args.key?(:name)
  @state = args[:state] if args.key?(:state)
  @task_restart_policy = args[:task_restart_policy] if args.key?(:task_restart_policy)
end