Class: Google::Apis::ManagedkafkaV1::ConsumerTopicMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/managedkafka_v1/classes.rb,
lib/google/apis/managedkafka_v1/representations.rb,
lib/google/apis/managedkafka_v1/representations.rb

Overview

Metadata for a consumer group corresponding to a specific topic.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ConsumerTopicMetadata

Returns a new instance of ConsumerTopicMetadata.



745
746
747
# File 'lib/google/apis/managedkafka_v1/classes.rb', line 745

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#partitionsHash<String,Google::Apis::ManagedkafkaV1::ConsumerPartitionMetadata>

Optional. Metadata for this consumer group and topic for all partition indexes it has metadata for. Corresponds to the JSON property partitions



743
744
745
# File 'lib/google/apis/managedkafka_v1/classes.rb', line 743

def partitions
  @partitions
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



750
751
752
# File 'lib/google/apis/managedkafka_v1/classes.rb', line 750

def update!(**args)
  @partitions = args[:partitions] if args.key?(:partitions)
end