Class: Google::Apis::ManagedkafkaV1::CreateVersionRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/managedkafka_v1/classes.rb,
lib/google/apis/managedkafka_v1/representations.rb,
lib/google/apis/managedkafka_v1/representations.rb

Overview

Request for CreateVersion.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CreateVersionRequest

Returns a new instance of CreateVersionRequest.



854
855
856
# File 'lib/google/apis/managedkafka_v1/classes.rb', line 854

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idFixnum

Optional. The schema ID of the schema. If not specified, the schema ID will be generated by the server. If the schema ID is specified, it must not be used by an existing schema that is different from the schema to be created. Corresponds to the JSON property id

Returns:

  • (Fixnum)


821
822
823
# File 'lib/google/apis/managedkafka_v1/classes.rb', line 821

def id
  @id
end

#normalizeBoolean Also known as: normalize?

Optional. If true, the schema will be normalized before being stored. The default is false. Corresponds to the JSON property normalize

Returns:

  • (Boolean)


827
828
829
# File 'lib/google/apis/managedkafka_v1/classes.rb', line 827

def normalize
  @normalize
end

#referencesArray<Google::Apis::ManagedkafkaV1::SchemaReference>

Optional. The schema references used by the schema. Corresponds to the JSON property references



833
834
835
# File 'lib/google/apis/managedkafka_v1/classes.rb', line 833

def references
  @references
end

#schemaString

Required. The schema payload Corresponds to the JSON property schema

Returns:

  • (String)


838
839
840
# File 'lib/google/apis/managedkafka_v1/classes.rb', line 838

def schema
  @schema
end

#schema_typeString

Optional. The type of the schema. It is optional. If not specified, the schema type will be AVRO. Corresponds to the JSON property schemaType

Returns:

  • (String)


844
845
846
# File 'lib/google/apis/managedkafka_v1/classes.rb', line 844

def schema_type
  @schema_type
end

#versionFixnum

Optional. The version to create. It is optional. If not specified, the version will be created with the max version ID of the subject increased by 1. If the version ID is specified, it will be used as the new version ID and must not be used by an existing version of the subject. Corresponds to the JSON property version

Returns:

  • (Fixnum)


852
853
854
# File 'lib/google/apis/managedkafka_v1/classes.rb', line 852

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



859
860
861
862
863
864
865
866
# File 'lib/google/apis/managedkafka_v1/classes.rb', line 859

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @normalize = args[:normalize] if args.key?(:normalize)
  @references = args[:references] if args.key?(:references)
  @schema = args[:schema] if args.key?(:schema)
  @schema_type = args[:schema_type] if args.key?(:schema_type)
  @version = args[:version] if args.key?(:version)
end