Class: Google::Apis::ManagedkafkaV1::ListConnectClustersResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/managedkafka_v1/classes.rb,
lib/google/apis/managedkafka_v1/representations.rb,
lib/google/apis/managedkafka_v1/representations.rb

Overview

Response for ListConnectClusters.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListConnectClustersResponse

Returns a new instance of ListConnectClustersResponse.



1058
1059
1060
# File 'lib/google/apis/managedkafka_v1/classes.rb', line 1058

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#connect_clustersArray<Google::Apis::ManagedkafkaV1::ConnectCluster>

The list of Connect clusters in the requested parent. Corresponds to the JSON property connectClusters



1045
1046
1047
# File 'lib/google/apis/managedkafka_v1/classes.rb', line 1045

def connect_clusters
  @connect_clusters
end

#next_page_tokenString

A token that can be sent as page_token to retrieve the next page of results. If this field is omitted, there are no more results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


1051
1052
1053
# File 'lib/google/apis/managedkafka_v1/classes.rb', line 1051

def next_page_token
  @next_page_token
end

#unreachableArray<String>

Locations that could not be reached. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


1056
1057
1058
# File 'lib/google/apis/managedkafka_v1/classes.rb', line 1056

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1063
1064
1065
1066
1067
# File 'lib/google/apis/managedkafka_v1/classes.rb', line 1063

def update!(**args)
  @connect_clusters = args[:connect_clusters] if args.key?(:connect_clusters)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end