Class: Google::Apis::ManagedkafkaV1::ListConsumerGroupsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/managedkafka_v1/classes.rb,
lib/google/apis/managedkafka_v1/representations.rb,
lib/google/apis/managedkafka_v1/representations.rb

Overview

Response for ListConsumerGroups.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListConsumerGroupsResponse

Returns a new instance of ListConsumerGroupsResponse.



1112
1113
1114
# File 'lib/google/apis/managedkafka_v1/classes.rb', line 1112

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#consumer_groupsArray<Google::Apis::ManagedkafkaV1::ConsumerGroup>

The list of consumer group in the requested parent. The order of the consumer groups is unspecified. Corresponds to the JSON property consumerGroups



1104
1105
1106
# File 'lib/google/apis/managedkafka_v1/classes.rb', line 1104

def consumer_groups
  @consumer_groups
end

#next_page_tokenString

A token that can be sent as page_token to retrieve the next page of results. If this field is omitted, there are no more results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


1110
1111
1112
# File 'lib/google/apis/managedkafka_v1/classes.rb', line 1110

def next_page_token
  @next_page_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1117
1118
1119
1120
# File 'lib/google/apis/managedkafka_v1/classes.rb', line 1117

def update!(**args)
  @consumer_groups = args[:consumer_groups] if args.key?(:consumer_groups)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
end