Class: Google::Apis::ManagedkafkaV1::LookupVersionRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/managedkafka_v1/classes.rb,
lib/google/apis/managedkafka_v1/representations.rb,
lib/google/apis/managedkafka_v1/representations.rb

Overview

Request for LookupVersion.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LookupVersionRequest

Returns a new instance of LookupVersionRequest.



1309
1310
1311
# File 'lib/google/apis/managedkafka_v1/classes.rb', line 1309

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#deletedBoolean Also known as: deleted?

Optional. If true, soft-deleted versions will be included in lookup, no matter if the subject is active or soft-deleted. If false, soft-deleted versions will be excluded. The default is false. Corresponds to the JSON property deleted

Returns:

  • (Boolean)


1284
1285
1286
# File 'lib/google/apis/managedkafka_v1/classes.rb', line 1284

def deleted
  @deleted
end

#normalizeBoolean Also known as: normalize?

Optional. If true, the schema will be normalized before being looked up. The default is false. Corresponds to the JSON property normalize

Returns:

  • (Boolean)


1291
1292
1293
# File 'lib/google/apis/managedkafka_v1/classes.rb', line 1291

def normalize
  @normalize
end

#referencesArray<Google::Apis::ManagedkafkaV1::SchemaReference>

Optional. The schema references used by the schema. Corresponds to the JSON property references



1297
1298
1299
# File 'lib/google/apis/managedkafka_v1/classes.rb', line 1297

def references
  @references
end

#schemaString

Required. The schema payload Corresponds to the JSON property schema

Returns:

  • (String)


1302
1303
1304
# File 'lib/google/apis/managedkafka_v1/classes.rb', line 1302

def schema
  @schema
end

#schema_typeString

Optional. The schema type of the schema. Corresponds to the JSON property schemaType

Returns:

  • (String)


1307
1308
1309
# File 'lib/google/apis/managedkafka_v1/classes.rb', line 1307

def schema_type
  @schema_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1314
1315
1316
1317
1318
1319
1320
# File 'lib/google/apis/managedkafka_v1/classes.rb', line 1314

def update!(**args)
  @deleted = args[:deleted] if args.key?(:deleted)
  @normalize = args[:normalize] if args.key?(:normalize)
  @references = args[:references] if args.key?(:references)
  @schema = args[:schema] if args.key?(:schema)
  @schema_type = args[:schema_type] if args.key?(:schema_type)
end