Class: Google::Apis::ManagedkafkaV1::SchemaConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/managedkafka_v1/classes.rb,
lib/google/apis/managedkafka_v1/representations.rb,
lib/google/apis/managedkafka_v1/representations.rb

Overview

SchemaConfig represents configuration for a schema registry or a specific subject.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SchemaConfig

Returns a new instance of SchemaConfig.



1652
1653
1654
# File 'lib/google/apis/managedkafka_v1/classes.rb', line 1652

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#aliasString

Optional. The subject to which this subject is an alias of. Only applicable for subject config. Corresponds to the JSON property alias

Returns:

  • (String)


1634
1635
1636
# File 'lib/google/apis/managedkafka_v1/classes.rb', line 1634

def alias
  @alias
end

#compatibilityString

Required. The compatibility type of the schema. The default value is BACKWARD. If unset in a SchemaSubject-level SchemaConfig, defaults to the global value. If unset in a SchemaRegistry-level SchemaConfig, reverts to the default value. Corresponds to the JSON property compatibility

Returns:

  • (String)


1641
1642
1643
# File 'lib/google/apis/managedkafka_v1/classes.rb', line 1641

def compatibility
  @compatibility
end

#normalizeBoolean Also known as: normalize?

Optional. If true, the schema will be normalized before being stored or looked up. The default is false. If unset in a SchemaSubject-level SchemaConfig, the global value will be used. If unset in a SchemaRegistry-level SchemaConfig, reverts to the default value. Corresponds to the JSON property normalize

Returns:

  • (Boolean)


1649
1650
1651
# File 'lib/google/apis/managedkafka_v1/classes.rb', line 1649

def normalize
  @normalize
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1657
1658
1659
1660
1661
# File 'lib/google/apis/managedkafka_v1/classes.rb', line 1657

def update!(**args)
  @alias = args[:alias] if args.key?(:alias)
  @compatibility = args[:compatibility] if args.key?(:compatibility)
  @normalize = args[:normalize] if args.key?(:normalize)
end