Class: Google::Apis::ManagedkafkaV1::TlsConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/managedkafka_v1/classes.rb,
lib/google/apis/managedkafka_v1/representations.rb,
lib/google/apis/managedkafka_v1/representations.rb

Overview

The TLS configuration for the Kafka cluster.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TlsConfig

Returns a new instance of TlsConfig.



1957
1958
1959
# File 'lib/google/apis/managedkafka_v1/classes.rb', line 1957

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ssl_principal_mapping_rulesString

Optional. A list of rules for mapping from SSL principal names to short names. These are applied in order by Kafka. Refer to the Apache Kafka documentation for ssl.principal.mapping.rules for the precise formatting details and syntax. Example: "RULE:^CN=(.?),OU=ServiceUsers.$/$1@example.com/,DEFAULT" This is a static Kafka broker configuration. Setting or modifying this field will trigger a rolling restart of the Kafka brokers to apply the change. An empty string means no rules are applied (Kafka default). Corresponds to the JSON property sslPrincipalMappingRules

Returns:

  • (String)


1950
1951
1952
# File 'lib/google/apis/managedkafka_v1/classes.rb', line 1950

def ssl_principal_mapping_rules
  @ssl_principal_mapping_rules
end

#trust_configGoogle::Apis::ManagedkafkaV1::TrustConfig

Sources of CA certificates to install in the broker's truststore. Corresponds to the JSON property trustConfig



1955
1956
1957
# File 'lib/google/apis/managedkafka_v1/classes.rb', line 1955

def trust_config
  @trust_config
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1962
1963
1964
1965
# File 'lib/google/apis/managedkafka_v1/classes.rb', line 1962

def update!(**args)
  @ssl_principal_mapping_rules = args[:ssl_principal_mapping_rules] if args.key?(:ssl_principal_mapping_rules)
  @trust_config = args[:trust_config] if args.key?(:trust_config)
end