Class: Google::Apis::ManagedkafkaV1::UpdateOptions

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/managedkafka_v1/classes.rb,
lib/google/apis/managedkafka_v1/representations.rb,
lib/google/apis/managedkafka_v1/representations.rb

Overview

UpdateOptions specifies options that influence how a cluster update is applied. These options control the behavior of the update process, rather than defining the desired end-state of a cluster.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UpdateOptions

Returns a new instance of UpdateOptions.



2019
2020
2021
# File 'lib/google/apis/managedkafka_v1/classes.rb', line 2019

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#allow_broker_downscale_on_cluster_upscaleBoolean Also known as: allow_broker_downscale_on_cluster_upscale?

Optional. If true, allows an update operation that increases the total vCPU and/or memory allocation of the cluster to significantly decrease the per- broker vCPU and/or memory allocation. This can result in reduced performance and availability. By default, the update operation will fail if an upscale request results in a vCPU or memory allocation for the brokers that is smaller than 90% of the current broker size. Corresponds to the JSON property allowBrokerDownscaleOnClusterUpscale

Returns:

  • (Boolean)


2016
2017
2018
# File 'lib/google/apis/managedkafka_v1/classes.rb', line 2016

def allow_broker_downscale_on_cluster_upscale
  @allow_broker_downscale_on_cluster_upscale
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2024
2025
2026
# File 'lib/google/apis/managedkafka_v1/classes.rb', line 2024

def update!(**args)
  @allow_broker_downscale_on_cluster_upscale = args[:allow_broker_downscale_on_cluster_upscale] if args.key?(:allow_broker_downscale_on_cluster_upscale)
end