Class: Google::Apis::ManagedkafkaV1::UpdateSchemaConfigRequest
- Inherits:
-
Object
- Object
- Google::Apis::ManagedkafkaV1::UpdateSchemaConfigRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/managedkafka_v1/classes.rb,
lib/google/apis/managedkafka_v1/representations.rb,
lib/google/apis/managedkafka_v1/representations.rb
Overview
Request for updating schema config. On a SchemaSubject-level SchemaConfig, an unset field will be removed from the SchemaConfig.
Instance Attribute Summary collapse
-
#compatibility ⇒ String
Required.
-
#normalize ⇒ Boolean
(also: #normalize?)
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UpdateSchemaConfigRequest
constructor
A new instance of UpdateSchemaConfigRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UpdateSchemaConfigRequest
Returns a new instance of UpdateSchemaConfigRequest.
2081 2082 2083 |
# File 'lib/google/apis/managedkafka_v1/classes.rb', line 2081 def initialize(**args) update!(**args) end |
Instance Attribute Details
#compatibility ⇒ String
Required. The compatibility type of the schemas. Cannot be unset for a
SchemaRegistry-level SchemaConfig. If unset on a SchemaSubject-level
SchemaConfig, removes the compatibility field for the SchemaConfig.
Corresponds to the JSON property compatibility
2070 2071 2072 |
# File 'lib/google/apis/managedkafka_v1/classes.rb', line 2070 def compatibility @compatibility end |
#normalize ⇒ Boolean Also known as: normalize?
Optional. If true, the schema will be normalized before being stored or looked
up. The default is false. Cannot be unset for a SchemaRegistry-level
SchemaConfig. If unset on a SchemaSubject-level SchemaConfig, removes the
normalize field for the SchemaConfig.
Corresponds to the JSON property normalize
2078 2079 2080 |
# File 'lib/google/apis/managedkafka_v1/classes.rb', line 2078 def normalize @normalize end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2086 2087 2088 2089 |
# File 'lib/google/apis/managedkafka_v1/classes.rb', line 2086 def update!(**args) @compatibility = args[:compatibility] if args.key?(:compatibility) @normalize = args[:normalize] if args.key?(:normalize) end |