Class: Google::Apis::ManagedkafkaV1::Cluster
- Inherits:
-
Object
- Object
- Google::Apis::ManagedkafkaV1::Cluster
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/managedkafka_v1/classes.rb,
lib/google/apis/managedkafka_v1/representations.rb,
lib/google/apis/managedkafka_v1/representations.rb
Overview
An Apache Kafka cluster deployed in a location.
Instance Attribute Summary collapse
-
#broker_details ⇒ Array<Google::Apis::ManagedkafkaV1::BrokerDetails>
Output only.
-
#capacity_config ⇒ Google::Apis::ManagedkafkaV1::CapacityConfig
A capacity configuration of a Kafka cluster.
-
#create_time ⇒ String
Output only.
-
#gcp_config ⇒ Google::Apis::ManagedkafkaV1::GcpConfig
Configuration properties for a Kafka cluster deployed to Google Cloud Platform.
-
#kafka_version ⇒ String
Output only.
-
#labels ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
Identifier.
-
#rebalance_config ⇒ Google::Apis::ManagedkafkaV1::RebalanceConfig
Defines rebalancing behavior of a Kafka cluster.
-
#satisfies_pzi ⇒ Boolean
(also: #satisfies_pzi?)
Output only.
-
#satisfies_pzs ⇒ Boolean
(also: #satisfies_pzs?)
Output only.
-
#state ⇒ String
Output only.
-
#tls_config ⇒ Google::Apis::ManagedkafkaV1::TlsConfig
The TLS configuration for the Kafka cluster.
-
#update_options ⇒ Google::Apis::ManagedkafkaV1::UpdateOptions
UpdateOptions specifies options that influence how a cluster update is applied.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Cluster
constructor
A new instance of Cluster.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Cluster
Returns a new instance of Cluster.
427 428 429 |
# File 'lib/google/apis/managedkafka_v1/classes.rb', line 427 def initialize(**args) update!(**args) end |
Instance Attribute Details
#broker_details ⇒ Array<Google::Apis::ManagedkafkaV1::BrokerDetails>
Output only. Only populated when FULL view is requested. Details of each
broker in the cluster.
Corresponds to the JSON property brokerDetails
354 355 356 |
# File 'lib/google/apis/managedkafka_v1/classes.rb', line 354 def broker_details @broker_details end |
#capacity_config ⇒ Google::Apis::ManagedkafkaV1::CapacityConfig
A capacity configuration of a Kafka cluster.
Corresponds to the JSON property capacityConfig
359 360 361 |
# File 'lib/google/apis/managedkafka_v1/classes.rb', line 359 def capacity_config @capacity_config end |
#create_time ⇒ String
Output only. The time when the cluster was created.
Corresponds to the JSON property createTime
364 365 366 |
# File 'lib/google/apis/managedkafka_v1/classes.rb', line 364 def create_time @create_time end |
#gcp_config ⇒ Google::Apis::ManagedkafkaV1::GcpConfig
Configuration properties for a Kafka cluster deployed to Google Cloud Platform.
Corresponds to the JSON property gcpConfig
369 370 371 |
# File 'lib/google/apis/managedkafka_v1/classes.rb', line 369 def gcp_config @gcp_config end |
#kafka_version ⇒ String
Output only. Only populated when FULL view is requested. The Kafka version of
the cluster.
Corresponds to the JSON property kafkaVersion
375 376 377 |
# File 'lib/google/apis/managedkafka_v1/classes.rb', line 375 def kafka_version @kafka_version end |
#labels ⇒ Hash<String,String>
Optional. Labels as key value pairs.
Corresponds to the JSON property labels
380 381 382 |
# File 'lib/google/apis/managedkafka_v1/classes.rb', line 380 def labels @labels end |
#name ⇒ String
Identifier. The name of the cluster. Structured like: projects/project_number
/locations/location/clusters/cluster_id
Corresponds to the JSON property name
386 387 388 |
# File 'lib/google/apis/managedkafka_v1/classes.rb', line 386 def name @name end |
#rebalance_config ⇒ Google::Apis::ManagedkafkaV1::RebalanceConfig
Defines rebalancing behavior of a Kafka cluster.
Corresponds to the JSON property rebalanceConfig
391 392 393 |
# File 'lib/google/apis/managedkafka_v1/classes.rb', line 391 def rebalance_config @rebalance_config end |
#satisfies_pzi ⇒ Boolean Also known as: satisfies_pzi?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzi
396 397 398 |
# File 'lib/google/apis/managedkafka_v1/classes.rb', line 396 def satisfies_pzi @satisfies_pzi end |
#satisfies_pzs ⇒ Boolean Also known as: satisfies_pzs?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzs
402 403 404 |
# File 'lib/google/apis/managedkafka_v1/classes.rb', line 402 def satisfies_pzs @satisfies_pzs end |
#state ⇒ String
Output only. The current state of the cluster.
Corresponds to the JSON property state
408 409 410 |
# File 'lib/google/apis/managedkafka_v1/classes.rb', line 408 def state @state end |
#tls_config ⇒ Google::Apis::ManagedkafkaV1::TlsConfig
The TLS configuration for the Kafka cluster.
Corresponds to the JSON property tlsConfig
413 414 415 |
# File 'lib/google/apis/managedkafka_v1/classes.rb', line 413 def tls_config @tls_config end |
#update_options ⇒ Google::Apis::ManagedkafkaV1::UpdateOptions
UpdateOptions specifies options that influence how a cluster update is applied.
These options control the behavior of the update process, rather than
defining the desired end-state of a cluster.
Corresponds to the JSON property updateOptions
420 421 422 |
# File 'lib/google/apis/managedkafka_v1/classes.rb', line 420 def @update_options end |
#update_time ⇒ String
Output only. The time when the cluster was last updated.
Corresponds to the JSON property updateTime
425 426 427 |
# File 'lib/google/apis/managedkafka_v1/classes.rb', line 425 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 |
# File 'lib/google/apis/managedkafka_v1/classes.rb', line 432 def update!(**args) @broker_details = args[:broker_details] if args.key?(:broker_details) @capacity_config = args[:capacity_config] if args.key?(:capacity_config) @create_time = args[:create_time] if args.key?(:create_time) @gcp_config = args[:gcp_config] if args.key?(:gcp_config) @kafka_version = args[:kafka_version] if args.key?(:kafka_version) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @rebalance_config = args[:rebalance_config] if args.key?(:rebalance_config) @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi) @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs) @state = args[:state] if args.key?(:state) @tls_config = args[:tls_config] if args.key?(:tls_config) @update_options = args[:update_options] if args.key?(:update_options) @update_time = args[:update_time] if args.key?(:update_time) end |