Class: Google::Apis::ManagedkafkaV1::ConnectCluster
- Inherits:
-
Object
- Object
- Google::Apis::ManagedkafkaV1::ConnectCluster
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/managedkafka_v1/classes.rb,
lib/google/apis/managedkafka_v1/representations.rb,
lib/google/apis/managedkafka_v1/representations.rb
Overview
An Apache Kafka Connect cluster deployed in a location.
Instance Attribute Summary collapse
-
#capacity_config ⇒ Google::Apis::ManagedkafkaV1::CapacityConfig
A capacity configuration of a Kafka cluster.
-
#config ⇒ Hash<String,String>
Optional.
-
#create_time ⇒ String
Output only.
-
#gcp_config ⇒ Google::Apis::ManagedkafkaV1::ConnectGcpConfig
Configuration properties for a Kafka Connect cluster deployed to Google Cloud Platform.
-
#kafka_cluster ⇒ String
Required.
-
#labels ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
Identifier.
-
#satisfies_pzi ⇒ Boolean
(also: #satisfies_pzi?)
Output only.
-
#satisfies_pzs ⇒ Boolean
(also: #satisfies_pzs?)
Output only.
-
#state ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ConnectCluster
constructor
A new instance of ConnectCluster.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ConnectCluster
Returns a new instance of ConnectCluster.
537 538 539 |
# File 'lib/google/apis/managedkafka_v1/classes.rb', line 537 def initialize(**args) update!(**args) end |
Instance Attribute Details
#capacity_config ⇒ Google::Apis::ManagedkafkaV1::CapacityConfig
A capacity configuration of a Kafka cluster.
Corresponds to the JSON property capacityConfig
478 479 480 |
# File 'lib/google/apis/managedkafka_v1/classes.rb', line 478 def capacity_config @capacity_config end |
#config ⇒ Hash<String,String>
Optional. Reserved for future use. This field is meant for worker config
overrides, but is unsupported for now.
Corresponds to the JSON property config
484 485 486 |
# File 'lib/google/apis/managedkafka_v1/classes.rb', line 484 def config @config end |
#create_time ⇒ String
Output only. The time when the cluster was created.
Corresponds to the JSON property createTime
489 490 491 |
# File 'lib/google/apis/managedkafka_v1/classes.rb', line 489 def create_time @create_time end |
#gcp_config ⇒ Google::Apis::ManagedkafkaV1::ConnectGcpConfig
Configuration properties for a Kafka Connect cluster deployed to Google Cloud
Platform.
Corresponds to the JSON property gcpConfig
495 496 497 |
# File 'lib/google/apis/managedkafka_v1/classes.rb', line 495 def gcp_config @gcp_config end |
#kafka_cluster ⇒ String
Required. Immutable. The name of the Kafka cluster this Kafka Connect cluster
is attached to. Structured like: projects/project/locations/location/
clusters/cluster
Corresponds to the JSON property kafkaCluster
502 503 504 |
# File 'lib/google/apis/managedkafka_v1/classes.rb', line 502 def kafka_cluster @kafka_cluster end |
#labels ⇒ Hash<String,String>
Optional. Labels as key value pairs.
Corresponds to the JSON property labels
507 508 509 |
# File 'lib/google/apis/managedkafka_v1/classes.rb', line 507 def labels @labels end |
#name ⇒ String
Identifier. The name of the Kafka Connect cluster. Structured like: projects/
project_number/locations/location/connectClusters/connect_cluster_id
Corresponds to the JSON property name
513 514 515 |
# File 'lib/google/apis/managedkafka_v1/classes.rb', line 513 def name @name end |
#satisfies_pzi ⇒ Boolean Also known as: satisfies_pzi?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzi
518 519 520 |
# File 'lib/google/apis/managedkafka_v1/classes.rb', line 518 def satisfies_pzi @satisfies_pzi end |
#satisfies_pzs ⇒ Boolean Also known as: satisfies_pzs?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzs
524 525 526 |
# File 'lib/google/apis/managedkafka_v1/classes.rb', line 524 def satisfies_pzs @satisfies_pzs end |
#state ⇒ String
Output only. The current state of the Kafka Connect cluster.
Corresponds to the JSON property state
530 531 532 |
# File 'lib/google/apis/managedkafka_v1/classes.rb', line 530 def state @state end |
#update_time ⇒ String
Output only. The time when the cluster was last updated.
Corresponds to the JSON property updateTime
535 536 537 |
# File 'lib/google/apis/managedkafka_v1/classes.rb', line 535 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
542 543 544 545 546 547 548 549 550 551 552 553 554 |
# File 'lib/google/apis/managedkafka_v1/classes.rb', line 542 def update!(**args) @capacity_config = args[:capacity_config] if args.key?(:capacity_config) @config = args[:config] if args.key?(:config) @create_time = args[:create_time] if args.key?(:create_time) @gcp_config = args[:gcp_config] if args.key?(:gcp_config) @kafka_cluster = args[:kafka_cluster] if args.key?(:kafka_cluster) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi) @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs) @state = args[:state] if args.key?(:state) @update_time = args[:update_time] if args.key?(:update_time) end |