Class: Google::Apis::ManagedkafkaV1::ConnectNetworkConfig
- Inherits:
-
Object
- Object
- Google::Apis::ManagedkafkaV1::ConnectNetworkConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/managedkafka_v1/classes.rb,
lib/google/apis/managedkafka_v1/representations.rb,
lib/google/apis/managedkafka_v1/representations.rb
Overview
The configuration of a Virtual Private Cloud (VPC) network that can access the Kafka Connect cluster.
Instance Attribute Summary collapse
-
#additional_subnets ⇒ Array<String>
Optional.
-
#dns_domain_names ⇒ Array<String>
Optional.
-
#primary_subnet ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ConnectNetworkConfig
constructor
A new instance of ConnectNetworkConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ConnectNetworkConfig
Returns a new instance of ConnectNetworkConfig.
619 620 621 |
# File 'lib/google/apis/managedkafka_v1/classes.rb', line 619 def initialize(**args) update!(**args) end |
Instance Attribute Details
#additional_subnets ⇒ Array<String>
Optional. Deprecated: Managed Kafka Connect clusters can now reach any
endpoint accessible from the primary subnet without the need to define
additional subnets. Please see https://cloud.google.com/managed-service-for-
apache-kafka/docs/connect-cluster/create-connect-cluster#worker-subnet for
more information.
Corresponds to the JSON property additionalSubnets
597 598 599 |
# File 'lib/google/apis/managedkafka_v1/classes.rb', line 597 def additional_subnets @additional_subnets end |
#dns_domain_names ⇒ Array<String>
Optional. Additional DNS domain names from the subnet's network to be made
visible to the Connect Cluster. When using MirrorMaker2, it's necessary to add
the bootstrap address's dns domain name of the target cluster to make it
visible to the connector. For example: my-kafka-cluster.us-central1.
managedkafka.my-project.cloud.goog
Corresponds to the JSON property dnsDomainNames
606 607 608 |
# File 'lib/google/apis/managedkafka_v1/classes.rb', line 606 def dns_domain_names @dns_domain_names end |
#primary_subnet ⇒ String
Required. VPC subnet to make available to the Kafka Connect cluster.
Structured like: projects/project/regions/region/subnetworks/subnet_id
It is used to create a Private Service Connect (PSC) interface for the Kafka
Connect workers. It must be located in the same region as the Kafka Connect
cluster. The CIDR range of the subnet must be within the IPv4 address ranges
for private networks, as specified in RFC 1918. The primary subnet CIDR range
must have a minimum size of /22 (1024 addresses).
Corresponds to the JSON property primarySubnet
617 618 619 |
# File 'lib/google/apis/managedkafka_v1/classes.rb', line 617 def primary_subnet @primary_subnet end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
624 625 626 627 628 |
# File 'lib/google/apis/managedkafka_v1/classes.rb', line 624 def update!(**args) @additional_subnets = args[:additional_subnets] if args.key?(:additional_subnets) @dns_domain_names = args[:dns_domain_names] if args.key?(:dns_domain_names) @primary_subnet = args[:primary_subnet] if args.key?(:primary_subnet) end |