Class: Google::Apis::ManagedkafkaV1::ConsumerGroup
- Inherits:
-
Object
- Object
- Google::Apis::ManagedkafkaV1::ConsumerGroup
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/managedkafka_v1/classes.rb,
lib/google/apis/managedkafka_v1/representations.rb,
lib/google/apis/managedkafka_v1/representations.rb
Overview
A Kafka consumer group in a given cluster.
Instance Attribute Summary collapse
-
#name ⇒ String
Identifier.
-
#topics ⇒ Hash<String,Google::Apis::ManagedkafkaV1::ConsumerTopicMetadata>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ConsumerGroup
constructor
A new instance of ConsumerGroup.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ConsumerGroup
Returns a new instance of ConsumerGroup.
697 698 699 |
# File 'lib/google/apis/managedkafka_v1/classes.rb', line 697 def initialize(**args) update!(**args) end |
Instance Attribute Details
#name ⇒ String
Identifier. The name of the consumer group. The consumer_group segment is
used when connecting directly to the cluster. Structured like: projects/
project/locations/location/clusters/cluster/consumerGroups/
consumer_group
Corresponds to the JSON property name
688 689 690 |
# File 'lib/google/apis/managedkafka_v1/classes.rb', line 688 def name @name end |
#topics ⇒ Hash<String,Google::Apis::ManagedkafkaV1::ConsumerTopicMetadata>
Optional. Metadata for this consumer group for all topics it has metadata for.
The key of the map is a topic name, structured like: projects/project/
locations/location/clusters/cluster/topics/topic
Corresponds to the JSON property topics
695 696 697 |
# File 'lib/google/apis/managedkafka_v1/classes.rb', line 695 def topics @topics end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
702 703 704 705 |
# File 'lib/google/apis/managedkafka_v1/classes.rb', line 702 def update!(**args) @name = args[:name] if args.key?(:name) @topics = args[:topics] if args.key?(:topics) end |