Class: Google::Apis::ManagedkafkaV1::ConsumerPartitionMetadata
- Inherits:
-
Object
- Object
- Google::Apis::ManagedkafkaV1::ConsumerPartitionMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/managedkafka_v1/classes.rb,
lib/google/apis/managedkafka_v1/representations.rb,
lib/google/apis/managedkafka_v1/representations.rb
Overview
Metadata for a consumer group corresponding to a specific partition.
Instance Attribute Summary collapse
-
#metadata ⇒ String
Optional.
-
#offset ⇒ Fixnum
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ConsumerPartitionMetadata
constructor
A new instance of ConsumerPartitionMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ConsumerPartitionMetadata
Returns a new instance of ConsumerPartitionMetadata.
724 725 726 |
# File 'lib/google/apis/managedkafka_v1/classes.rb', line 724 def initialize(**args) update!(**args) end |
Instance Attribute Details
#metadata ⇒ String
Optional. The associated metadata for this partition, or empty if it does not
exist.
Corresponds to the JSON property metadata
716 717 718 |
# File 'lib/google/apis/managedkafka_v1/classes.rb', line 716 def @metadata end |
#offset ⇒ Fixnum
Required. The current offset for this partition, or 0 if no offset has been
committed.
Corresponds to the JSON property offset
722 723 724 |
# File 'lib/google/apis/managedkafka_v1/classes.rb', line 722 def offset @offset end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
729 730 731 732 |
# File 'lib/google/apis/managedkafka_v1/classes.rb', line 729 def update!(**args) @metadata = args[:metadata] if args.key?(:metadata) @offset = args[:offset] if args.key?(:offset) end |