Class: Google::Apis::ManagedkafkaV1::GcpConfig
- Inherits:
-
Object
- Object
- Google::Apis::ManagedkafkaV1::GcpConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/managedkafka_v1/classes.rb,
lib/google/apis/managedkafka_v1/representations.rb,
lib/google/apis/managedkafka_v1/representations.rb
Overview
Configuration properties for a Kafka cluster deployed to Google Cloud Platform.
Instance Attribute Summary collapse
-
#access_config ⇒ Google::Apis::ManagedkafkaV1::AccessConfig
The configuration of access to the Kafka cluster.
-
#kms_key ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GcpConfig
constructor
A new instance of GcpConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GcpConfig
Returns a new instance of GcpConfig.
921 922 923 |
# File 'lib/google/apis/managedkafka_v1/classes.rb', line 921 def initialize(**args) update!(**args) end |
Instance Attribute Details
#access_config ⇒ Google::Apis::ManagedkafkaV1::AccessConfig
The configuration of access to the Kafka cluster.
Corresponds to the JSON property accessConfig
911 912 913 |
# File 'lib/google/apis/managedkafka_v1/classes.rb', line 911 def access_config @access_config end |
#kms_key ⇒ String
Optional. Immutable. The Cloud KMS Key name to use for encryption. The key
must be located in the same region as the cluster and cannot be changed.
Structured like: projects/project/locations/location/keyRings/key_ring/
cryptoKeys/crypto_key.
Corresponds to the JSON property kmsKey
919 920 921 |
# File 'lib/google/apis/managedkafka_v1/classes.rb', line 919 def kms_key @kms_key end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
926 927 928 929 |
# File 'lib/google/apis/managedkafka_v1/classes.rb', line 926 def update!(**args) @access_config = args[:access_config] if args.key?(:access_config) @kms_key = args[:kms_key] if args.key?(:kms_key) end |