Class: Google::Apis::ManagedkafkaV1::NetworkConfig
- Inherits:
-
Object
- Object
- Google::Apis::ManagedkafkaV1::NetworkConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/managedkafka_v1/classes.rb,
lib/google/apis/managedkafka_v1/representations.rb,
lib/google/apis/managedkafka_v1/representations.rb
Overview
The configuration of a Virtual Private Cloud (VPC) network that can access the Kafka cluster.
Instance Attribute Summary collapse
-
#subnet ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NetworkConfig
constructor
A new instance of NetworkConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NetworkConfig
Returns a new instance of NetworkConfig.
1337 1338 1339 |
# File 'lib/google/apis/managedkafka_v1/classes.rb', line 1337 def initialize(**args) update!(**args) end |
Instance Attribute Details
#subnet ⇒ String
Required. Name of the VPC subnet in which to create Private Service Connect (
PSC) endpoints for the Kafka brokers and bootstrap address. Structured like:
projects/project/regions/region/subnetworks/subnet_id The subnet must be
located in the same region as the Kafka cluster. The project may differ.
Multiple subnets from the same parent network must not be specified.
Corresponds to the JSON property subnet
1335 1336 1337 |
# File 'lib/google/apis/managedkafka_v1/classes.rb', line 1335 def subnet @subnet end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1342 1343 1344 |
# File 'lib/google/apis/managedkafka_v1/classes.rb', line 1342 def update!(**args) @subnet = args[:subnet] if args.key?(:subnet) end |