Class: Google::Apis::ManagedkafkaV1::RemoveAclEntryResponse
- Inherits:
-
Object
- Object
- Google::Apis::ManagedkafkaV1::RemoveAclEntryResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/managedkafka_v1/classes.rb,
lib/google/apis/managedkafka_v1/representations.rb,
lib/google/apis/managedkafka_v1/representations.rb
Overview
Response for RemoveAclEntry.
Instance Attribute Summary collapse
-
#acl ⇒ Google::Apis::ManagedkafkaV1::Acl
Represents the set of ACLs for a given Kafka Resource Pattern, which consists of resource_type, resource_name and pattern_type.
-
#acl_deleted ⇒ Boolean
(also: #acl_deleted?)
Returned with value true if the removed acl entry was the last entry in the acl, resulting in acl deletion.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RemoveAclEntryResponse
constructor
A new instance of RemoveAclEntryResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RemoveAclEntryResponse
Returns a new instance of RemoveAclEntryResponse.
1531 1532 1533 |
# File 'lib/google/apis/managedkafka_v1/classes.rb', line 1531 def initialize(**args) update!(**args) end |
Instance Attribute Details
#acl ⇒ Google::Apis::ManagedkafkaV1::Acl
Represents the set of ACLs for a given Kafka Resource Pattern, which consists
of resource_type, resource_name and pattern_type.
Corresponds to the JSON property acl
1522 1523 1524 |
# File 'lib/google/apis/managedkafka_v1/classes.rb', line 1522 def acl @acl end |
#acl_deleted ⇒ Boolean Also known as: acl_deleted?
Returned with value true if the removed acl entry was the last entry in the
acl, resulting in acl deletion.
Corresponds to the JSON property aclDeleted
1528 1529 1530 |
# File 'lib/google/apis/managedkafka_v1/classes.rb', line 1528 def acl_deleted @acl_deleted end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1536 1537 1538 1539 |
# File 'lib/google/apis/managedkafka_v1/classes.rb', line 1536 def update!(**args) @acl = args[:acl] if args.key?(:acl) @acl_deleted = args[:acl_deleted] if args.key?(:acl_deleted) end |