Class: Google::Apis::ManagedkafkaV1::SchemaMode
- Inherits:
-
Object
- Object
- Google::Apis::ManagedkafkaV1::SchemaMode
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/managedkafka_v1/classes.rb,
lib/google/apis/managedkafka_v1/representations.rb,
lib/google/apis/managedkafka_v1/representations.rb
Overview
SchemaMode represents the mode of a schema registry or a specific subject. Four modes are supported: * NONE: deprecated. This was the default mode for a subject, but now the default is unset (which means use the global schema registry setting) * READONLY: The schema registry is in read-only mode. * READWRITE: The schema registry is in read-write mode, which allows limited write operations on the schema. * IMPORT: The schema registry is in import mode, which allows more editing operations on the schema for data importing purposes.
Instance Attribute Summary collapse
-
#mode ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SchemaMode
constructor
A new instance of SchemaMode.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SchemaMode
Returns a new instance of SchemaMode.
1681 1682 1683 |
# File 'lib/google/apis/managedkafka_v1/classes.rb', line 1681 def initialize(**args) update!(**args) end |
Instance Attribute Details
#mode ⇒ String
Required. The mode type of a schema registry (READWRITE by default) or of a
subject (unset by default, which means use the global schema registry setting).
Corresponds to the JSON property mode
1679 1680 1681 |
# File 'lib/google/apis/managedkafka_v1/classes.rb', line 1679 def mode @mode end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1686 1687 1688 |
# File 'lib/google/apis/managedkafka_v1/classes.rb', line 1686 def update!(**args) @mode = args[:mode] if args.key?(:mode) end |