Class: Google::Apis::ManagedkafkaV1::UpdateSchemaConfigRequest
- Inherits:
-
Object
- Object
- Google::Apis::ManagedkafkaV1::UpdateSchemaConfigRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/managedkafka_v1/classes.rb,
lib/google/apis/managedkafka_v1/representations.rb,
lib/google/apis/managedkafka_v1/representations.rb
Overview
Request for updating schema config. On a SchemaSubject-level SchemaConfig, an unset field will be removed from the SchemaConfig.
Instance Attribute Summary collapse
-
#compatibility ⇒ String
Required.
-
#normalize ⇒ Boolean
(also: #normalize?)
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UpdateSchemaConfigRequest
constructor
A new instance of UpdateSchemaConfigRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UpdateSchemaConfigRequest
Returns a new instance of UpdateSchemaConfigRequest.
2050 2051 2052 |
# File 'lib/google/apis/managedkafka_v1/classes.rb', line 2050 def initialize(**args) update!(**args) end |
Instance Attribute Details
#compatibility ⇒ String
Required. The compatibility type of the schemas. Cannot be unset for a
SchemaRegistry-level SchemaConfig. If unset on a SchemaSubject-level
SchemaConfig, removes the compatibility field for the SchemaConfig.
Corresponds to the JSON property compatibility
2039 2040 2041 |
# File 'lib/google/apis/managedkafka_v1/classes.rb', line 2039 def compatibility @compatibility end |
#normalize ⇒ Boolean Also known as: normalize?
Optional. If true, the schema will be normalized before being stored or looked
up. The default is false. Cannot be unset for a SchemaRegistry-level
SchemaConfig. If unset on a SchemaSubject-level SchemaConfig, removes the
normalize field for the SchemaConfig.
Corresponds to the JSON property normalize
2047 2048 2049 |
# File 'lib/google/apis/managedkafka_v1/classes.rb', line 2047 def normalize @normalize end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2055 2056 2057 2058 |
# File 'lib/google/apis/managedkafka_v1/classes.rb', line 2055 def update!(**args) @compatibility = args[:compatibility] if args.key?(:compatibility) @normalize = args[:normalize] if args.key?(:normalize) end |